pub enum LayoutTable<'a> {
Gsub(Gsub<'a>),
Gpos(Gpos<'a>),
}Variants
Implementations
Sourceimpl<'a> LayoutTable<'a>
impl<'a> LayoutTable<'a>
fn script_list(&self) -> Option<ScriptList<'a>>
fn feature_list(&self) -> Option<FeatureList<'a>>
fn feature_variations(&self) -> Option<FeatureVariations<'a>>
fn script(&self, index: u16) -> Option<Script<'a>>
fn langsys_index(&self, script_index: u16, tag: hb_tag_t) -> Option<u16>
fn langsys( &self, script_index: u16, langsys_index: Option<u16>, ) -> Option<LangSys<'a>>
pub(crate) fn feature(&self, index: u16) -> Option<Feature<'a>>
fn feature_tag(&self, index: u16) -> Option<hb_tag_t>
pub(crate) fn feature_variation_index(&self, coords: &[F2Dot14]) -> Option<u32>
pub(crate) fn feature_substitution( &self, variation_index: u32, feature_index: u16, ) -> Option<Feature<'a>>
pub(crate) fn feature_index(&self, tag: hb_tag_t) -> Option<u16>
pub(crate) fn lookup_count(&self) -> u16
Sourcepub(crate) fn select_script(
&self,
script_tags: &[hb_tag_t],
) -> Option<(bool, u16, hb_tag_t)>
pub(crate) fn select_script( &self, script_tags: &[hb_tag_t], ) -> Option<(bool, u16, hb_tag_t)>
Returns true + index and tag of the first found script tag in the given GSUB or GPOS table or false + index and tag if falling back to a default script.
Sourcepub(crate) fn select_script_language(
&self,
script_index: u16,
lang_tags: &[hb_tag_t],
) -> Option<u16>
pub(crate) fn select_script_language( &self, script_index: u16, lang_tags: &[hb_tag_t], ) -> Option<u16>
Returns the index of the first found language tag in the given GSUB or GPOS table, underneath the specified script index.